package PureMessage::WebUI::Controller::Password;
use strict;
use warnings;
use PureMessage::WebUI::RunModeException;
use base 'Exporter';
our @EXPORT_OK = qw/handle_change_password/;

sub handle_change_password {
    my ($app) = @_;
    my $query = $app->query;
    my $context = $app->{context};
    my $loc = $context->{loc};
    my $user = $context->{user};

    die PureMessage::WebUI::MessagePreviewException->new(prohibited => 1)
        unless $user->any_group_can('change_password');

    return unless $query->param('submitted');

    eval {
        my $old_pw = $query->param('old_password');
        my $new_pw = $query->param('new_password');
        my $cnf_pw = $query->param('confirm_password');

        die $loc->("Please supply your old password.\n") unless $old_pw;
        die $loc->("Please supply a new password.\n") unless $new_pw;
        die $loc->("New passwords do not match!\n") unless $new_pw eq $cnf_pw;

        my $valid = $user->validate($context->{username}, $old_pw);
        die $loc->("Old password is not correct!\n") unless $valid;

        # Everything is good, change the password
        $user->set_passphrase($new_pw);
        $context->{result_msg} = $loc->("Password change successful.");
        $app->log('Password changed');
    };
    if ($@) {
        $context->{change_error} = $@;
        $app->log($@);
    }
}

1;
