package PureMessage::WebUI::I18N;

use strict;
use warnings;
use base qw(Locale::Maketext);
use PureMessage::Config qw(%config);
use PureMessage::Version qw($PREFIX);

sub get_handle_via_config {
    my $class = shift;
    if (my $lang = $config{language}) {        
        my $lh = $class->get_handle($lang);
        return $lh if defined $lh;
    }
    # default to English
    return $class->get_handle('en');
}

sub language_tag {
    return 'en';  # default to English
}

my $IMG_URL_BASE = q{/groups/images};
my $STATIC_BASE  = q{var/www/group-static/images};

sub image_info {
    my ($self, $image) = @_;
    my $lang = $self->language_tag;
    my $static_dir = "$STATIC_BASE/$lang";
    unless (-e "$PREFIX/$static_dir/$image") {
        $lang = 'en';
        $static_dir = "$STATIC_BASE/en";
    }
    return (
        language    => $lang, 
        static_dir  => $static_dir,
        static_path => "$PREFIX/$static_dir/$image",
        www_path    => "$IMG_URL_BASE/$lang/$image",
    );
}

sub make_image_path {
    my ($self, $image) = @_;
    my %image_info = $self->image_info($image);
    return $image_info{www_path};
}

1;

