package PureMessage::WebUI::RunModeException;
use strict;
use warnings;

sub new {
    my ($proto, %opts) = @_;
    my $class = ref($proto) || $proto;
    my $self = \%opts;
    bless($self, $class);

    $self->{caller} = join(':', caller);
    return $self;
}

sub error_message {
    return $_[0]->{error_msg} || '';
}

sub caller { $_[0]->{caller} }

sub redirect {
    return $_[0]->{redirect} || '';
}

sub prohibited { $_[0]->{prohibited} }

package PureMessage::WebUI::MessagePreviewException;
use strict;
use warnings;
use base 'PureMessage::WebUI::RunModeException';

sub new {
    my ($class, %opts) = @_;
    $opts{message_preview} = 1;
    my $self = $class->SUPER::new(%opts);
    $self->{caller} = join(':', caller);
    return $self;
}

package PureMessage::WebUI::AccessException;
use strict;
use warnings;
use base 'PureMessage::WebUI::RunModeException';

sub new {
    my ($class, %opts) = @_;
    die "Must specify permission" unless $opts{perm};
    $opts{error_msg} = "No access to $opts{perm}";
    my $self = $class->SUPER::new(%opts);
    $self->{caller} = join(':', caller);
    return $self;
}

package PureMessage::WebUI::ValidationException;
use strict;
use warnings;
use base 'PureMessage::WebUI::RunModeException';

sub new {
    my ($class, %opts) = @_;
    die "Must provide valid parameters" unless $opts{error_msg};
    my $self = $class->SUPER::new(%opts);
    $self->{caller} = join(':', caller);
    return $self;
}

1;

