// DOM extension functions for WWW-Ajapi
//

function clearChildNodes (node) {
    // a node's nodelist changes automatically as we remove it's nodes,
    // so we have to copy the nodelist first.
    if(!node.childNodes || !node.childNodes.length) {
        return;
    }

    var nl = new Array();
    var i;
    
    for(i=0;i<node.childNodes.length;i++) {
        nl.push(node.childNodes[i]);
    }
    
    for(i=0;i<nl.length;i++) {
        node.removeChild(nl[i]);
    }
    
    return;
}

function setFormValues_checkbox (eles, val) {
    var ii;
    var ih = new Hash;
    
    for(ii=0;ii<val.length;ii++) {
        var checkVal = val[ii];
        ih[checkVal] = 1;
    }
    
    for(ii=0;ii<eles.length;ii++) {
        var checkVal = eles[ii].getAttribute('value');
        if(ih[checkVal]) {
            eles[ii].checked = 1;
        } else {
            eles[ii].checked = 0;
        }
    }
}

function setFormValues_text (eles, val) {
    for(ii=0;ii<val.length;ii++) {
        if(eles[ii] && val[ii] != null) {
            eles[ii].value = val[ii];
        }
    }
}

function setFormValues_select (eles, val) {
    var ele = eles[0];
    
    // since SELECT boxes can have multiple options, having
    // multiple SELECT boxes with the same name doesn't make much
    // sense. We may wish to revisit this logic in the future.
    
    if(eles[1]) {
        throw new Error(
            'Multiple SELECT elements with the same name? ("' +
            eles[1].getAttribute('name') + '")'
         );
    }
    
    var i;
    var ah = new Hash;
    for(i=0;i<val.length;i++) {
        ah[val[i]] = 1;0
    }

    ele.selectedIndex = -1;

    for(i=0;i<ele.options.length;i++) {
        var myval = ele.options[i].value || ele.options[i].text;
        if(ah[myval]) {
            ele.options[i].selected = 1;
        } else {
            ele.options[i].selected = 0;
        }
    }
}

function setFormValues_span (nodes, data) {
    var node = nodes[0];
    clearChildNodes(node);
    var text = node.ownerDocument.createTextNode(data);
    node.appendChild(text);
    return;
}

function setFormValues (node, data) {
    var i, keys;
    keys = Hash.prototype.keys.call(data);
    var form_data = elementsHavingHash.apply(this, [ node, 'name' ].concat(keys));
    for(i=0;i<keys.length;i++) {
        var eles = form_data[keys[i]];
        var val = data[keys[i]];
        
        if(!Array.prototype.isPrototypeOf(val)) {
            val = new String(val);
            val = new Array(val);
        }
        
        if(eles && eles.length) {
            var tname = eles[0].tagName.toUpperCase();
            if(tname == 'INPUT') {
                var tt = eles[0].getAttribute('type').toLowerCase();
                if(tt == 'checkbox' || tt == 'radio') {
                    setFormValues_checkbox(eles, val);
                } else if(tt == 'text' || tt == 'hidden' || tt == 'password') {
                    setFormValues_text(eles, val);
                } else {
                    throw new Error('setFormValues() does not know how to handle INPUT tag type "' + tt + '"');
                }
            } else if(tname == 'SELECT') {
                setFormValues_select(eles, val);
            } else if(tname == 'TEXTAREA') {
                setFormValues_text(eles, val);
            } else if(tname == 'SPAN') {
                setFormValues_span(eles, val);
            } else {
                throw new Error('setFormValues() does not know how to handle tag type "' + tname + '"');
            }
        }
    }
    return form_data;
}

function getFormValues_input (node, name, eh) {
    if(!eh) {
        eh = elementsHaving(node, 'name', name)
    }
    var rv = new Array();
    var i;
    for(i=0;i<eh.length;i++) {
        var j;
        if(eh[i].value) {
            rv.push(eh[i].value);
        }
    }
    
    if(rv.length) {
        if(eh.length == 1) {
            return rv[0];
        } else {
            return rv;
        }
    } else {
        return;
    }
}

function getFormValues_checkbox (node, name, eh) {
    if(!eh) {
        eh = elementsHaving(node, 'name', name)
    }

    var tt = eh[0].getAttribute('type').toLowerCase();
    var rv = new Array();
    var i;
    for(i=0;i<eh.length;i++) {
        if(eh[i].checked) {
        
            rv.push(eh[i].getAttribute('value'));
        
        } else {
          // if it's boolean then set the opposite value
          if(eh[i].getAttribute('value') == '1') {
            rv.push(0);
          }else if (eh[i].getAttribute('value') == '0') {
            rv.push(1);
          }
        }
    }
    
    if(rv.length) {
        if(tt == 'radio') {
            return rv[0];
        } else {
	    if(eh.length == 1) {
              return rv[0];
            } else {
              return rv;
            }
        }
    } else {
        return;
    }
}

function getFormValues_select (node, name, eh) {
    if(!eh) {
        eh = elementsHaving(node, 'name', name);
    }
    
    if(eh[1]) {
        throw new Error('Multiple SELECT elements with same name? ("' +
            name + '")');
    }
    
    var rv = new Array();
    var i;
    
    for(i=0; i<eh[0].options.length; i++) {
        if(eh[0].options[i].selected) {
            var val = eh[0].options[i].value || eh[0].options[i].text;
            rv.push(val);
        }
    }
    
    if(rv.length) {
        if(eh[0].type == 'select-one') {
            return rv[0];
        } else {
            return rv;
        }
    } else {
        return;
    }
}

function getFormValues (node, keys) {
    // this method won''t do mixed types (eg; TEXT and CHECKBOX with same name)
    // properly.
    var i, ii;
    ii = 0;
    var rv = new Hash();
    var form_data = elementsHavingHash.apply(this, [ node, 'name' ].concat(keys));
    for(i=0;i<keys.length;i++) {
        var ele = form_data[keys[i]];
        if(ele) {
            var rr;
            var tname = ele[0].tagName.toUpperCase();
             
            if(tname == 'INPUT') {
                var tt = ele[0].getAttribute('type').toLowerCase();
                if(tt == 'radio' || tt == 'checkbox') {
                    rr = getFormValues_checkbox(node, keys[i], ele);
                } else if(tt == 'text' || tt == 'hidden' || tt == 'password' || !tt) {
                    rr = getFormValues_input(node, keys[i], ele);
                } else {
                    throw new Error('getFormValues() does not know how to handle INPUT type ' + tt);
                }
                if(rr != null) {
                    rv[keys[i]] = rr;
                    ii++;
                }
            } else if(tname == 'SELECT') {
                rr = getFormValues_select(node, keys[i], ele);
                if(rr != null) {
                    rv[keys[i]] = rr;
                    ii++;
                }
            } else if(tname == 'TEXTAREA') {
                rr = getFormValues_input(node, keys[i], ele);
            } else if(tname == 'SPAN') {
                1;
            } else {
                throw new Error('getFormValues() does not know how to handle tag type ' + tname);
            }
        }
    }
    return rv;
}

function enumerateChildren (node, callback, args) {
    var rv = new Array();
    var i;
    if(node && node.childNodes) {
        for(i=0;i<node.childNodes.length;i++) {
            var xnode = node.childNodes[i];
            var subrv = callback(xnode, args);
            if(subrv) {
                rv = rv.concat(subrv);
            }
        
            if(xnode.childNodes && xnode.childNodes.length) {
                var subrv = enumerateChildren(xnode, callback, args);
                if(subrv) {
                    rv = rv.concat(subrv);
                }
            }
        }
    }
    return rv;
}

function elementsHavingHash (node, attribute) {
    var i, ri;
    var rv = new Hash();
    ri=0;

    var values = new Array;;
    for(i=2;i<arguments.length;i++) {
    	values.push(arguments[i]);
    }

    var rrv = enumerateChildren(node,
	function (node, args) {
	    if(node.getAttribute) {
		for (var i=0; i<args.values.length; i++) {
		    if(node.getAttribute(args.attribute) == args.values[i]) {
			if (args.rv[args.values[i]] == undefined) {
			    args.rv[args.values[i]] = new Array();
			}
			args.rv[args.values[i]].push(node);
			return;
		    }
		}
	    }
	    return;
	},
	{ attribute :attribute, values : values, rv : rv }
    );

    return rv;
}

// deal with stupid M$IE's disregard for DOM
function elementsHavingClass (node, className) {
    var rv = enumerateChildren(node,
        function (node, className) {
            if(node.className && node.className == className) {
                return node;
            } else {
                return;
            }
        },
        className
    );
    
    return rv;
}

function elementsHaving (node, attribute, value) {
    var rv = enumerateChildren(node,
        function (node, args) {
            if(node.getAttribute) {
		var attval = node.getAttribute(args.attribute);

		// if the user called elementsHaving without a value argument,
		// then they are checking for the attributes existence
		if (!args.hasvalue && attval != undefined) {
		    return node;
		}
		else if (args.hasvalue && attval == args.value) {
		    return node;
		}
            }
            return;
        },
        { attribute : attribute, value : value, hasvalue : arguments.length == 3 }
    );
    
    return rv;
}

// *matching*, not "having"
function elementsMatchingId (node, matchId) {
    var rv = enumerateChildren(node,
       function (node, matchId) {
            if(node.id && node.id.match(matchId)) {
                return node;
            } else {
                return;
            }
        },
        matchId
    );
    return rv;
}

// *matching*, not "having"
function elementsMatchingClass (node, matchClass) {
    var rv = enumerateChildren(node,
       function (node, matchClass) {
            if(node.className && node.className.match(matchClass)) {
                return node;
            } else {
                return;
            }
        },
        matchClass
    );
    return rv;
}

function parentHaving (node, attribute, value) {
    var rn, pn;
    
    for(pn=node.parentNode; pn && !rn; pn=pn.parentNode) {
        if(pn.getAttribute && pn.getAttribute(attribute) == value) {
            rn = pn;
        }
    }

    if(rn) {
        return rn;
    } else {
        return;
    }
}

function addHandler (node, handler, funct) {
    if (document.all) { // IE:
	node[ handler.toLowerCase() ] = new Function (funct);
    } else { // Others:
	node.setAttribute(handler, funct);
    }
}

// this function is deprecated. button.js handles form tweaking now.
function setupForm () {
    return false;
}

function getSelectedRange (node) {
    if (document.selection) { // IE:
	var range = document.selection.createRange();
	var start = node.value.indexOf(range.text);
	if (!range.text.length) {
	    return [0,0]; // nothing is selected
	}
	return [ start, start + range.text.length ];
    }
    else {
	if (node.selectionStart == node.selectionEnd) {
	    return [0,0]; // nothing is selected
	}
	return [ node.selectionStart, node.selectionEnd ];
    }
}

function setSelectedRange (node, left, right) {
    if (node.createTextRange) { // IE:
	var range = node.createTextRange();
	range.collapse(true);
	range.moveEnd('character',right);
	range.moveStart('character',left);
	range.select();
    }
    else {
	node.focus();
	node.setSelectionRange(left, right);
    }
}

function Widget (node) {
    var wnode = 0;
    if(node.getAttribute) {
        if(node.getAttribute('name') == 'Widget') {
            wnode = node;
        }
    }

    if(!wnode) {
         wnode = parentHaving(node, 'name','Widget');
    }
    
    if(wnode && wnode.getAttribute) {
        var iid;
        if(iid = wnode.getAttribute('id')) {
            if(AjapiObjects[iid]) {
                return AjapiObjects[iid];
            } else {
                throw new Error(
                    'Reference to non-existant Ajapi widget' +
                    'ID "' + iid + '" (referenced by ' + this +
                    ' does not exist in AjapiObject array.'
                );
            }
        }
    }
}


// Check if an element is visible or has enherited visibility from an 
// ancestor node

function isVisible (el) {
    if (el.style == undefined) {
	throw new Error("isVisible() called on a non-styled element");
    }
    if (document.defaultView) { 
        var cs = document.defaultView.getComputedStyle(el,'');
	return cs.getPropertyValue('visibility') == 'visible';
    }
    else if (el.currentStyle) {
        var cs = el.currentStyle;
        var val = cs['visibility'];
        if (val == 'inherit' && el.parentNode.style) {
            return this.isVisible(el.parentNode);
        }
        return val == 'visible' || val == 'inherit';
    }
    return false;
};


// Check if an element has its display value set to 'none' or if an
// ancestor node has it set

function isDisplayable (el) {
    if (el.style == undefined) {
	    throw new Error("isDisplayable() called on a non-styled element");
    }
    if (document.defaultView) { 
        var cs = document.defaultView.getComputedStyle(el,'');
        var disp = cs.getPropertyValue('display');
        if ( el.parentNode.style && disp != 'none' ) {
            if (el === document) {
                return true;
            }
            return this.isDisplayable(el.parentNode);
        }
    	return disp != 'none';
    }
    else if (el.currentStyle) {
        var cs = el.currentStyle;
        var val = cs['display'];
        if (val == 'block' && el.parentNode.style) {
            return this.isDisplayable(el.parentNode);
        }
        return val != 'none' || val == 'block';
    }
    return false;
};


function isViewable (el) {
    return isVisible(el) && isDisplayable(el);
}

// somewhat braindead URL query parser, to be used for really simple stuff
// only... ideally, this will eventually handle ';' separation, URI decoding,
// etc.

function GET_args () {
    var q = location.search;
    if(q.length > 1) {
        q = q.substring(1, q.length);
    } else {
        // no arguments
        return this;
    }
    
    var split1 = q.split('&');
    
    for(var i = 0; i < split1.length; i++) {
        var pair = split1[i].split('=');
        this[pair[0]] = pair[1];
    }
    
    return this;
}



// define a function that the appliance has but the pm version of this package doesn't
var innerText;
if(!innerText) {
    innerText = function (node, text) {
            var attr = document.all ? 'innerText' : 'textContent';
            if (node == undefined) {
                throw new Error("error attempting to set inner text " +
                                "of an undefined node to '" + text + "'");
            }
            if (arguments.length == 2) {
                node[attr] = text;
            }
            return node[attr];
        }

}

function text_sane(val) {
    return val.replace(/\s+$/,'').replace(/^\s+/,'').replace(/[^\w\-]+$/,'').replace(/^[^\w\-]+/,'').replace(/[\n\r]/g,'').replace(/&nbsp;/,' ').replace(/\s+/g, ' ');
}

function resetLogSearchPage() {
    var labels = new Array('Action','Reason','Results to Return');
    var temp;

    for(var ix=0; ix < labels.length; ix++) {
       temp = get_element_by_selector('select',labels[ix]);
       if(labels[ix].match('Results to Return')) {
         temp.found[0].selectedIndex = 1;
       } else {
         temp.found[0].selectedIndex = 0;
       }
    }
    labels = new Array('Sender','Recipient','Start Date Range','End Date Range','Host','ID');

    for(var ix=0; ix < labels.length; ix++) {
       temp = get_element_by_selector('input',labels[ix]);
       temp.found[0].value = '';
    }
}

function get_messages_by_content(criteria) {

  var found = new Array();
  var resultTable = document.getElementById("searchResultsBody");
  var messageRows = new Array();
  messageRows = elementsMatchingClass(resultTable, "datarow");

  // only look for those in the data table
  for(var selix = 0; selix < messageRows.length; selix++) {
      var testing = messageRows[selix];

      if( testing && isViewable(testing) ) {
          if ( testing.className && (testing.className  == 'datarow') || (testing.className  == 'datarowAlt') ) {
            var cells = testing.cells;
            var row_item = new Object();

            // gather the attributes for each message
            for(var ix = 0; ix < cells.length; ix++) {
              var cur_cell = cells[ix];
              if( cur_cell.id ) {
                // subject's id is in the td
                if ( cur_cell.id.match('subject') ) {
                    row_item.subject = text_sane(innerText(cur_cell));
                }
              }

              var spans = cur_cell.getElementsByTagName('span');
              var cur_el = spans[0];
              if( cur_el && cur_el.id ) {
                // all the other id's are in spans 
                if( cur_el.id.match('date') ) {
                    row_item.date = text_sane(innerText(cur_el));

                } else if ( cur_el.id.match('from') ) {
                    row_item.sender = text_sane(innerText(cur_el));

                } else if ( cur_el.id.match('to') ) {
                    row_item.recipient = text_sane(innerText(cur_el));

                } else if ( cur_el.id.match('reason') ) {
                    row_item.reason = text_sane(innerText(cur_el));

                } else if ( cur_el.id.match('action') ) {
                    row_item.action = text_sane(innerText(cur_el));
                }
              }

            }

            row_item.number = selix + 1;

            // now check if it matches
            var match = 1;

            if ( criteria.sender && !row_item.sender.match(criteria.sender) ) {
                match = 0;
            }
            if ( criteria.recipient && !row_item.recipient.match(criteria.recipient) ) {
                match = 0;
            } 
            if ( criteria.subject && !row_item.subject.match(criteria.subject) ) {
                match = 0;
            }
            if ( criteria.reason && !row_item.reason.match(criteria.reason) ) {
                match = 0;
            }
            if ( criteria.action && !row_item.action.match(criteria.action) ) {
                match = 0;
            }
            if ( criteria.date && !row_item.date.match(criteria.date) ) {
                match = 0;
            }
            if ( criteria.number ) {

                if ( criteria.number == "first" ) {
                    if ( row_item.number != 1 ) {
                        match = 0;
                    }
                } else if ( criteria.number == "last" ) {
                    if ( row_item.number != messageRows.length ) {
                        match = 0;
                    }
                } else if ( row_item.number != criteria.number ) {
                    match = 0;
                }
            }

            if (match) {
              found.push(row_item);
            }
            
        }
      }
  }
  return found;
}


function get_element_by_selector(typ,value) {

  var found = new Array();
  var itm = new Array();
  typ = typ.toLowerCase();

  if (typ == 'label') {
      itm = document.getElementsByTagName('label');
      for(var ix =0; ix < itm.length; ix++) {
        if ( ( isViewable(itm[ix]) ) && ( itm[ix].innerHTML == value ) ) {
          found.push(itm[ix]);
        }
      }

  } else if (typ == 'select') {

      var result =  get_element_by_selector('label',value);
     
      if (result.msg) {
        return result;
      }

      itm = result.found;

      if (itm.length > 1) {

         return { msg: 'Duplicate labels for select found' };
      
      } else if (itm.length == 0 ) {

         return { found : found };
      }

      var label = itm[0]; 
      var possible_elements = document.getElementsByName(label.htmlFor);
      var select_elements_that_fit_criteria = new Array();

      // try and find the first visible select
      for(var selix = 0; selix <= possible_elements.length; selix++) {
        if ( possible_elements[selix] && isViewable(possible_elements[selix]) ) {
            if (possible_elements[selix].tagName == 'SELECT') {
              select_elements_that_fit_criteria.push(possible_elements[selix]);
            }
        }
      }

      if (select_elements_that_fit_criteria.length > 1) {
         return { msg: 'Duplicate selects found for the label "' + label.htmlFor + '"'};
      } else if (select_elements_that_fit_criteria.length == 0) {
          return { found : found }
      } else {
          // return the only element we found
          found.push(select_elements_that_fit_criteria[0]);
      }

  } else if (typ == 'selectwith') {

      itm =  document.getElementsByTagName('select');

      if (itm.length == 0 ) {
         return { found : found };
      }

      for (var ix = 0; ix < itm.length; ix++) {
        var select = itm[ix];
        var options = select.getElementsByTagName('option');
        var txt = new Array(); 

        for (var optix =0; optix < options.length; optix++) {
          var tmp = options[optix].innerHTML;
          tmp = tmp.replace(/[^\w]+$/,'');
          txt.push(tmp);
        }
        if (txt.join('/') == value ) {
          found.push(select);
        }
      }

  } else if (typ == 'input') {

      var result =  get_element_by_selector('label',value);
     
      if (result.msg) {
        return result;
      }

      itm = result.found;

      if (itm.length > 1) {

         return { msg: 'Duplicate labels for input found' };
      
      } else if (itm.length == 0 ) {

         return { found : found };
      }

      var label = itm[0]; 

      var possible_elements = document.getElementsByName(label.htmlFor);

      // try and find the first visible input
      for(var selix = 0; selix <= possible_elements.length; selix++) {
        if ( possible_elements[selix] && isViewable(possible_elements[selix]) ) {
            var vis = isViewable(possible_elements[selix]);
            if ( (possible_elements[selix].tagName == 'INPUT') && (possible_elements[selix].type.toLowerCase() != 'hidden') ) {
              found.push(possible_elements[selix]);
            }
        }
      }

  } else if (typ == 'header') {

      var possible_elements =  document.getElementsByTagName('th');
      
      // try and find the first visible input
      for(var selix = 0; selix <= possible_elements.length; selix++) {
        if ( possible_elements[selix] && isViewable(possible_elements[selix]) ) {
            var tmp = innerText(possible_elements[selix]);
            tmp = tmp.replace(/[^\w]+$/,'').replace(/^[^\w]+/,'');
            if (tmp == value) {
              found.push(possible_elements[selix]);
            }
        }
      }


  } else if (typ == 'button') {

      var possible_elements =  document.getElementsByTagName('button');
      
      // try and find the first visible input
      for(var selix = 0; selix <= possible_elements.length; selix++) {
        if ( possible_elements[selix] && isViewable(possible_elements[selix]) ) {
            var tmp = innerText(possible_elements[selix]);
            tmp = tmp.replace(/[^\w]+$/,'').replace(/^[^\w]+/,'');
            if (tmp == value) {
              var node = possible_elements[selix].getElementsByTagName('a');
              found.push(node[0]);
            }
        }
      }

  } else if (typ == 'message') {

      var possible_elements = document.getElementsByTagName('tr');

      // only look for those in the data table
      for(var selix = 0; selix <= possible_elements.length; selix++) {
          var testing = possible_elements[selix];
          if( testing && isViewable(testing) ){
              if ( testing.className && (testing.className  == 'datarow') || (testing.className  == 'datarowAlt') ) {
                var tmp = innerText(testing);
                // strip out the date
                var tmp = text_sane( innerText(testing) );
                var time_str = text_sane( innerText( testing.cells[0] ) );
                var time_re = new RegExp(time_str);
                tmp = tmp.replace(time_re, '');
                new_value = text_sane(value.replace(time_re, ''));
                if ( tmp.match(new_value) ) {
                  found.push(testing);
                }
              }
          }
      } 
  }

  return { found: found };

}

function get_element_contents_by_selector(typ,value) {

  var found = new Array();
  var itm = new Array();
  var result;

  result = get_element_by_selector(typ,value);
  
  if (result.msg) {
    return result.msg;
  }

  if ((! typeof(result.found) == 'ARRAY' ) || ( result.found.length == 0 ) ) {
    return "No elements matching that criteria could be found.";
  }

  itm = result.found;
 
  if (typ == 'input') { 

     found.push(value);

  } else if (typ == 'message') {

      for(var ix =0; ix < itm.length; ix++) {
            var tmp = innerText(itm[ix]);
            tmp = text_sane(tmp);
            // strip out the date
            var time_str = text_sane( innerText( itm[ix].cells[0] ) );
            var time_re = new RegExp(time_str);
            tmp = tmp.replace(time_re, '');
            found.push(tmp);
      }        
  
  } else if (typ == 'selectwith' || typ == 'select') {
     
      var options = itm[0].getElementsByTagName('option');

      for(var ix =0; ix < options.length; ix++) {
          var tmp = options[ix].innerHTML;
          tmp = tmp.replace(/[^\w]+$/,'');
          found.push(tmp);
      }

  } else {
     // label, header, button 

      for(var ix =0; ix < itm.length; ix++) {
            var tmp = innerText(itm[ix]);
            tmp = tmp.replace(/[^\w]+$/,'').replace(/^[^\w]+/,'');
            found.push(tmp);
      }        

  } 

  if (found.length) {
     var txt = found.join('/');
     return txt;
  } else {
     return 'not ok';
  }
}

var sortCol = 0;  // default: date
var ascending = false;

function rowSorter (a, b) {

    if (a.cells[sortCol] && b.cells[sortCol]) {

        var attr = document.all ? 'innerText' : 'textContent';
        if (a.cells[sortCol][attr] > b.cells[sortCol][attr]) {
            return 1;
        } else if (a.cells[sortCol][attr] ==  b.cells[sortCol][attr]) {
            return 0;
        } else {
            return -1;
        }
    } 
    return 0;
}

var lastSortedOn = 'none';

function sortOnColumn (col, el) {

    if (col == lastSortedOn) {
        ascending = !ascending;
    } else {
        ascending = 1;
    }
    lastSortedOn = col;

    var resultTable = document.getElementById("searchResultsBody");
    var rows = new Array();
    rows = elementsMatchingClass(resultTable, "datarow");

    if (rows.length) {
        // Find the column index for the cell we're looking for
        var cells = elementsMatchingClass(rows[0], col);
        if (cells.length) {
            sortCol = cells[0].cellIndex;
        }
    }

    // Do the sort
    rows.sort(rowSorter);
    if (!ascending) {
        rows.reverse();
    }

    // Fix up the alternating colours for the table rows
    var classThing = 'datarow';
    for (var i = 0; i < rows.length; i++) {
        var curRow = rows[i];
        curRow.className = classThing;
        classThing = (classThing == 'datarow') ? 'datarowAlt' : 'datarow';
        resultTable.appendChild(curRow);
    }

    // Now switch the image
    var no_sort_image = "/groups/images/btn_order_noselect.gif";
    var sort_image_descending = "/groups/images/btn_order_descending.gif";
    var sort_image_ascending = "/groups/images/btn_order_ascending.gif";
    
    var possibles = elementsHavingClass(el,'sortByImg');
    var img = possibles[0];

    var allImages = elementsHavingClass(document.getElementById('resultTableColumnHeadingTable'),'sortByImg'); 
    for (var ix =0; ix < allImages.length; ix++) {
        allImages[ix].src = no_sort_image;
    }


    if (ascending) {
        img.src = sort_image_ascending; 
    } else {
        img.src = sort_image_descending;
    }

}

function getColumnSortButtonId (col) {

    var sortHeader = document.getElementById("resultTableColumnHeadingTable");
    var links = elementsMatchingId(sortHeader, "sort_" + col);

    if (links.length) {

        return links[0].id;

    } else {

        return "Error: no matching links found!";
    }
} 

GET_args.prototype = new Hash();
